knit v0.4.0 Knit

Handles populating models.

Summary

Functions

Populate a knit struct from a map

Populate a list of knit structs from a list of maps

Functions

populate(params, module)
populate(map, module) :: struct

Populate a knit struct from a map.

populate_list(params, module)
populate_list(map, module) :: struct

Populate a list of knit structs from a list of maps.