Handles populating models.
Populate a knit struct from a map
Populate a list of knit structs from a list of maps
populate(map, module) :: struct
Populate a knit struct from a map.
populate_list(map, module) :: struct
Populate a list of knit structs from a list of maps.